Feedback | Office Angels UK
Description: Whether you are dissatisfied about your experience with us or are really happy, let us know.
Keywords: feedback, office, angels,

[City],[Region],[Country],[Province],[PostalCode]
[City],[Province]

- [enter text]
- Adecco World

- Find a job
- Help & advice
- Working with you

bckTop,brdCrmb,shrBtn_Bottom,shrBtn

### Find a job

- Help & advice

- Working with you

- Sign up for job alerts

- Our branches

# Feedback

Help us to improve our service.

We actively seek your feedback to make sure our services meet your needs.

So whether you are dissatisfied about your experience with us or are really happy, let us know. Your comment will be sent directly to our Head Office who will deal with it appropriately.

Please ensure all the fields are correctly filled. Thanks Your Name * Email Address* Your Message* hdTextboxforCheckboxState

### Recent
news

### Workers are clueless on auto-enrolment of pen... A half (48%) of UK workers have not been sufficiently informed about auto enrolment by their employ... Read more Office Angels is tackling youth unemployment ... With youth unemployment at an all time high, we’ve stepped up to encourage, motivate and inspire peo... Read more Two-thirds of office workers sit at their des... - 18 March 2013 Read more PreviousNext
### Latest tweets ## Join us on: ## Receive job alerts

### Find a job Job search Find a branch | ### Jobseekers Advice for jobseekers Skills & training News & opinion | ### Employers Working with you Advice for employers Who we work with | ### News & opinion News Blogs Employment law | ### About us The Adecco Group Our diversity partners Careers

- © Office Angels 2013
- Contact us
- Feedback
- Terms & Conditions
- Privacy Policy
- Cookie Policy
- Press office
- Careers at Office Angels

x

## Receive jobs by email matching:

close
close
close
close
close
close
close